<?php
declare(strict_types=1);

namespace Inti\Wp\Provider\Type\Post;

use Inti\Wp\Provider\Type\AbstractWpType;

/**
 * Class AbstractPostType
 *
 * @package Inti\Wp\Provider\Post
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp-provider
 */
class AbstractPostType extends AbstractWpType implements PostTypeInterface
{
    protected string  $capability_type     = 'post';
    protected ?bool   $exclude_from_search = null;
    /** @var bool|string */
    protected         $has_archive         = false;
    protected ?string $label               = null;
    protected ?bool   $map_meta_cap        = null;
    protected ?string $menu_icon           = null;
    protected ?int    $menu_position       = null;
    protected ?bool   $show_in_admin_bar   = null;
    protected array   $supports            = [];
    protected array   $taxonomies          = [];

    public function getCapabilityType(): string
    {
        return $this->capability_type;
    }

    public function getLabel(): string
    {
        return $this->label ?? ($this->getLabels()['name'] ?? '');
    }

    public function getMenuIcon(): ?string
    {
        return $this->menu_icon;
    }

    public function getMenuPosition(): ?int
    {
        return $this->menu_position;
    }

    public function getObjectType(): string
    {
        return 'post';
    }

    public function getSupportedFeatures(): array
    {
        return $this->supports;
    }

    public function getTaxonomies(): array
    {
        return $this->taxonomies;
    }

    public function hasArchive()
    {
        return $this->has_archive;
    }

    public function isExcludedFromSearch(): ?bool
    {
        return $this->exclude_from_search;
    }

    public function mapMetaCap(): ?bool
    {
        return $this->map_meta_cap;
    }

    public function showInAdminBar(): ?bool
    {
        return $this->show_in_admin_bar;
    }
}
