<?php
/** @noinspection PhpUnusedPrivateFieldInspection */
declare(strict_types=1);

namespace IntiTest\Wp\Provider\Plugin;

use Inti\Provider\Service\ProviderManager;
use IntiTest\Wp\Provider\AbstractTestCase;
use IntiTest\Wp\Provider\Mock;

use function get_post_meta;
use function get_term_meta;

/**
 * Class ProvideMetadataTest
 *
 * @package IntiTest\Wp\Provider\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-wp-provider
 *
 * @runTestsInSeparateProcesses
 */
final class ProvideMetadataTest extends AbstractTestCase
{
    private array $config = [
        ProviderManager::class => [
            'registered' => [
                Mock\PostMetadataProvider::class,
                Mock\TermMetadataProvider::class,
            ],
        ],
    ];

    public function testCanProvidePostMetadata()
    {
        $this->assertEquals([
            '_post_meta1' => ['post meta value 1-1'],
            '_post_meta2' => ['post meta value 1-2'],
        ], get_post_meta(1));
    }

    public function testCanProvidePostMetadataForKey()
    {
        $this->assertEquals('post meta value 1-1', get_post_meta(1, '_post_meta1', true));
    }

    public function testCanProvideTermMetadata()
    {
        $this->assertEquals([
            '_term_meta1' => ['term meta value 1-1'],
            '_term_meta2' => ['term meta value 1-2'],
        ], get_term_meta(1));
    }

    public function testCanProvideTermMetadataForKey()
    {
        $this->assertEquals('term meta value 1-1', get_term_meta(1, '_term_meta1', true));
    }
}
